==> ZenTaoPMS.15.2.zip: zentaopms/module/user/lang/de.php <==
<?php
/**
 * The user module English file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL (http://zpl.pub/page/zplv12.html)
 * @author      Chunsheng Wang <chunsheng@cnezsoft.com>
 * @package     user
 * @version     $Id: en.php 5053 2013-07-06 08:17:37Z wyd621@gmail.com $
 * @link        http://www.zentao.net
 */
$lang->user->common           = 'Benutzer';
$lang->user->id               = 'ID';
$lang->user->inside           = 'Inside Members';
$lang->user->outside          = 'Outside Members';
$lang->user->company          = 'Unternehmen';
$lang->user->dept             = 'Abteilung';
$lang->user->account          = 'Konto';
$lang->user->password         = 'Passwort';
$lang->user->password2        = 'Passwort wiederholen';
$lang->user->role             = 'Rolle';
$lang->user->group            = 'Gruppe';
$lang->user->realname         = 'Name';
$lang->user->nickname         = 'Spitzname';
$lang->user->commiter         = 'SCM User';
$lang->user->birthyear        = 'Geburtsdatum';
$lang->user->gender           = 'Geschlecht';
$lang->user->email            = 'Email';
$lang->user->basicInfo        = 'Basis Info';
$lang->user->accountInfo      = 'Konto';
$lang->user->verify           = 'Bestätigen';
$lang->user->contactInfo      = 'Kontakt';
$lang->user->skype            = 'Skype';
$lang->user->qq               = 'QQ';
$lang->user->mobile           = 'Mobil';
$lang->user->phone            = 'Telefon';
$lang->user->weixin           = 'WeChat';
$lang->user->dingding         = 'DingDing';
$lang->user->slack            = 'Slack';
$lang->user->whatsapp         = 'WhatsApp';
$lang->user->address          = 'Adresse';
$lang->user->zipcode          = 'PLZ';
$lang->user->join             = 'Beigetreten am';
$lang->user->visits           = 'Besuche';
$lang->user->ip               = 'Letzte IP';
$lang->user->last             = 'Letztes Login';
$lang->user->ranzhi           = 'Zdoo Konto';
$lang->user->ditto            = 'Dito';
$lang->user->originalPassword = 'Altes Passwort';
$lang->user->newPassword      = 'New Password';
$lang->user->verifyPassword   = 'Ihr Login Passwort';
$lang->user->resetPassword    = 'Passwort vergessen?';
$lang->user->score            = 'Score';
$lang->user->name             = 'Name';
$lang->user->type             = 'User Type';
$lang->user->cropAvatar       = 'Crop Avatar';
$lang->user->cropAvatarTip    = 'Drag and drop the box to select the image clipping range.';
$lang->user->cropImageTip     = 'The image used is too small, the recommended image size is at least 48x48, the current image size is %s';

$lang->user->legendBasic        = 'Basic Information';
$lang->user->legendContribution = 'Contribution';

$lang->user->index         = "Home";
$lang->user->view          = "Übersicht";
$lang->user->create        = "Benutzer erstellen";
$lang->user->batchCreate   = "Mehrere erstellen";
$lang->user->edit          = "Bearbeiten";
$lang->user->batchEdit     = "Mehrere bearbeiten";
$lang->user->unlock        = "Entsperren";
$lang->user->delete        = "Löschen";
$lang->user->unbind        = "Zdoo verbindung aufheben";
$lang->user->login         = "Anmelden";
$lang->user->bind          = "Bind User";
$lang->user->oauthRegister = "Register a new account";
$lang->user->mobileLogin   = "Mobil";
$lang->user->editProfile   = "Bearbeiten";
$lang->user->deny          = "Zugriff verweigert.";
$lang->user->confirmDelete = "Möchten Sie diesen Benutzer löschen?";
$lang->user->confirmUnlock = "Möchten Sie diese Benutzer entsperren?";
$lang->user->confirmUnbind = "Möchten Sie dei Verknüpfung zu Zdoo aufheben?";
$lang->user->relogin       = "Erneut anmelden";
$lang->user->asGuest       = "Gast";
$lang->user->goback        = "Zurück";
$lang->user->deleted       = '(Gelöscht)';
$lang->user->search        = 'Suche';
$lang->user->else          = 'Else';

$lang->user->saveTemplate          = 'Save as Template';
$lang->user->setPublic             = 'Set as Public Template';
$lang->user->deleteTemplate        = 'Delete Template';
$lang->user->setTemplateTitle      = 'Please enter the title of template.';
$lang->user->applyTemplate         = 'Templates';
$lang->user->confirmDeleteTemplate = 'Do you want to delete this template?';
$lang->user->setPublicTemplate     = 'Set as Public Template';
$lang->user->tplContentNotEmpty    = 'Vorlageninhalt darf nicht leer sein!';

$lang->user->profile   = 'Profil';
$lang->user->project   = $lang->executionCommon;
$lang->user->execution = 'Execution';
$lang->user->task      = 'Aufgaben';
$lang->user->bug       = 'Bugs';
$lang->user->test      = 'Tests';
$lang->user->testTask  = 'Testaufgaben';
$lang->user->testCase  = 'Testfälle';
$lang->user->issue     = 'Issue';
$lang->user->risk      = 'Risk';
$lang->user->schedule  = 'Schedule';
$lang->user->todo      = 'Todos';
$lang->user->story     = 'Story';
$lang->user->dynamic   = 'Verlauf';

$lang->user->openedBy    = 'Geöffnet';
$lang->user->assignedTo  = 'Zugeordnet';
$lang->user->finishedBy  = 'Abgeschlossen';
$lang->user->resolvedBy  = 'Gelöst';
$lang->user->closedBy    = 'Geschlossen';
$lang->user->reviewedBy  = 'Überprüft';
$lang->user->canceledBy  = 'Abgebrochen';

$lang->user->testTask2Him = 'Build';
$lang->user->case2Him     = 'Fall zugeordnet';
$lang->user->caseByHim    = 'Fall geöffnet';

$lang->user->errorDeny    = "Sorry, your access to <b>%s</b> of <b>%s</b> is denied. Please contact your Admin to get privileges. Return to home page or login again.";
$lang->user->errorView    = "Sorry, your access view <b>%s</b> is denied. Please contact your Admin to get privileges. Return to home page or login again.";
$lang->user->loginFailed  = "Login fehlgeschlagen. Bitte prüfen Sie Ihren Benutzernamen und das Passwort.";
$lang->user->lockWarning  = "Sie haben %s Versuche.";
$lang->user->loginLocked  = "Bitte kontaktieren Sie den Administrator um Ihr Konto entsperren zu lassen oder versuchen Sie in %s Minuten noch ein mal.";
$lang->user->weakPassword = "Ihr Passwort entspricht nicht den Anforderungen.";
$lang->user->errorWeak    = "Passwords cannot use [%s] these commonly used weak passwords.";

$lang->user->roleList['']       = '';
$lang->user->roleList['dev']    = 'Developer';
$lang->user->roleList['qa']     = 'QS';
$lang->user->roleList['pm']     = 'Scrum Master';
$lang->user->roleList['po']     = 'Product Owner';
$lang->user->roleList['td']     = 'Technischer Manager';
$lang->user->roleList['pd']     = 'Produkt Manager';
$lang->user->roleList['qd']     = 'QS Manager';
$lang->user->roleList['top']    = 'Senior Manager';
$lang->user->roleList['others'] = 'Andere';

$lang->user->genderList['m'] = 'Männlich';
$lang->user->genderList['f'] = 'Weiblich';

$lang->user->thirdPerson['m'] = 'Him';
$lang->user->thirdPerson['f'] = 'Her';

$lang->user->typeList['inside']  = $lang->user->inside;
$lang->user->typeList['outside'] = $lang->user->outside;

$lang->user->passwordStrengthList[0] = "<span style='color:red'>Schwach</span>";
$lang->user->passwordStrengthList[1] = "<span style='color:#000'>Gut</span>";
$lang->user->passwordStrengthList[2] = "<span style='color:green'>Stark</span>";

$lang->user->statusList['active'] = 'Aktiviert';
$lang->user->statusList['delete'] = 'Gelöscht';

$lang->user->personalData['createdTodos']        = 'Todos Created';
$lang->user->personalData['createdRequirements'] = "Requirements Created";
$lang->user->personalData['createdStories']      = "Stories Created";
$lang->user->personalData['finishedTasks']       = 'Tasks Finished';
$lang->user->personalData['createdBugs']         = 'Bugs Created';
$lang->user->personalData['resolvedBugs']        = 'Bugs Resolved';
$lang->user->personalData['createdCases']        = 'Cases Created';
$lang->user->personalData['createdRisks']        = 'Risks Created';
$lang->user->personalData['resolvedRisks']       = 'Risks Resolved';
$lang->user->personalData['createdIssues']       = 'Issues Created';
$lang->user->personalData['resolvedIssues']      = 'Issues Resolved';
$lang->user->personalData['createdDocs']         = 'Docs Created';

$lang->user->keepLogin['on']      = 'Angemeldet bleiben';
$lang->user->loginWithDemoUser    = 'Login als Demo User:';

$lang->user->tpl = new stdclass();
$lang->user->tpl->type    = 'Typ';
$lang->user->tpl->title   = 'TPL Titel';
$lang->user->tpl->content = 'Inhalt';
$lang->user->tpl->public  = 'Öffentlich';

$lang->usertpl = new stdclass();
$lang->usertpl->title = 'Template Name';

$lang->user->placeholder = new stdclass();
$lang->user->placeholder->account   = 'Buchstaben, Understrich und Ziffern. Mindestens 3 Zeichen';
$lang->user->placeholder->password1 = 'Mindestens 6 Zeichen ';
$lang->user->placeholder->role      = "Rolle betrifft Inhalt und die Benutzerreihenfolge.";
$lang->user->placeholder->group     = "Die Gruppe bestimmt die Benutzerrechte.";
$lang->user->placeholder->commiter  = 'SVN/Git Konto';
$lang->user->placeholder->verify    = 'Bitte geben Sie Ihr Login Passwort ein.';

$lang->user->placeholder->passwordStrength[1] = 'Buchstaben und Ziffern. Mindestens 6 Zeichen';
$lang->user->placeholder->passwordStrength[2] = 'Buchstaben, Ziffern und Sonderzeichen. Mindestens 10 Zeichen';

$lang->user->error = new stdclass();
$lang->user->error->account        = "ID %s，Konto muss Buchstaben, Unterstriche oder Ziffern enthalten. Mindestens 3 Zeichen.";
$lang->user->error->accountDupl    = "ID %s，Konto wurde genutzt.";
$lang->user->error->realname       = "ID %s，muss der Realname sein";
$lang->user->error->password       = "ID %s，passwort muss mindestens 6 Zeichen lang sein.";
$lang->user->error->mail           = "ID %s，bitte geben Sie eine gültige Emailadresse an.";
$lang->user->error->reserved       = "ID %s，Konto ist reserviert.";
$lang->user->error->weakPassword   = "ID %s，the password strength is less than the system setting.";
$lang->user->error->dangerPassword = "ID %s，Passwords cannot be used with [%s] these commonly used if-passwords.";

$lang->user->error->verifyPassword   = "Verifikation fehlgeschlagen. Bitte geben Sie ihr Loginpasswort ein.";
$lang->user->error->originalPassword = "Altes Passwort ist falsch.";
$lang->user->error->noAccess         = "This user is not from your department. You have no access to this user information.";

$lang->user->contactFieldList['phone']    = $lang->user->phone;
$lang->user->contactFieldList['mobile']   = $lang->user->mobile;
$lang->user->contactFieldList['qq']       = $lang->user->qq;
$lang->user->contactFieldList['dingding'] = $lang->user->dingding;
$lang->user->contactFieldList['weixin']   = $lang->user->weixin;
$lang->user->contactFieldList['skype']    = $lang->user->skype;
$lang->user->contactFieldList['slack']    = $lang->user->slack;
$lang->user->contactFieldList['whatsapp'] = $lang->user->whatsapp;

$lang->user->executionTypeList['stage']  = 'Stage';
$lang->user->executionTypeList['sprint'] = $lang->iterationCommon;

$lang->user->contacts = new stdclass();
$lang->user->contacts->common   = 'Kontakt';
$lang->user->contacts->listName = 'Namensliste';
$lang->user->contacts->userList = 'Benutzerliste';

$lang->user->contacts->manage        = 'Verwalten';
$lang->user->contacts->contactsList  = 'Kontakte';
$lang->user->contacts->selectedUsers = 'Auswahl';
$lang->user->contacts->selectList    = 'Liste';
$lang->user->contacts->createList    = 'Erstelle Kontaktliste';
$lang->user->contacts->noListYet     = 'Es existiert keine Kontaktliste. Bitte erstellen Sie eine.';
$lang->user->contacts->confirmDelete = 'Möchten Sie diese Liste löschen?';
$lang->user->contacts->or            = ' oder ';

$lang->user->resetFail       = "Fehlgeschlagen. Bitte prüfen Sie das Konto";
$lang->user->resetSuccess    = "Zurückgesetzt! Bitte nutzen Sie Ihr neues Passwort, um sich anzumelden.";
$lang->user->noticeResetFile = "<h5>Kontaktieren Sie den Administrator um Ihr Passwort zurückzusetzen.</h5>
    <h5>Wenn Sie der Administrator sind, meleden Sie sich auf dem Server an und erstellen Sie die Datei <span> '%s' </span>.</h5>
    <p>Hinweis:</p>
    <ol>
    <li>Die Datei muss leer sein.</li>
    <li>Wenn die Datei bereits existiert löschen Sie diese und erstellen Sie eine neue.</li>
    </ol>";
$lang->user->notice4Safe = "Warning: Weak password of one click package detected";
$lang->user->process4DIR = "It is detected that you may be using the one click installation package environment. Other sites in the environment are still using simple passwords. For security reasons, if you do not use other sites, please handle them in time. Delete or rename the %s directory. Visit: <a href='https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html' target='_blank'>https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html</a>";
$lang->user->process4DB  = "It is detected that you may be using the one click installation package environment. Other sites in the environment are still using simple passwords. For security reasons, if you do not use other sites, please handle them in time. Please login database and modify password field of zt_user table of %s database. Visit: <a href='https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html' target='_blank'>https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html</a>";
$lang->user->mkdirWin = <<<EOT
    <html><head><meta charset='utf-8'></head>
    <body><table align='center' style='width:700px; margin-top:100px; border:1px solid gray; font-size:14px;'><tr><td style='padding:8px'>
    <div style='margin-bottom:8px;'>不能创建临时目录，请确认目录<strong style='color:#ed980f'>%s</strong>是否存在并有操作权限。</div> 
    <div>Can't create tmp directory, make sure the directory <strong style='color:#ed980f'>%s</strong> exists and has permission to operate.</div>
    </td></tr></table></body></html>
EOT;
$lang->user->mkdirLinux = <<<EOT
    <html><head><meta charset='utf-8'></head>
    <body><table align='center' style='width:700px; margin-top:100px; border:1px solid gray; font-size:14px;'><tr><td style='padding:8px'>
    <div style='margin-bottom:8px;'>不能创建临时目录，请确认目录<strong style='color:#ed980f'>%s</strong>是否存在并有操作权限。</div>  
    <div style='margin-bottom:8px;'>命令为：<strong style='color:#ed980f'>chmod o=rwx -R %s</strong>。</div>
    <div>Can't create tmp directory, make sure the directory <strong style='color:#ed980f'>%s</strong> exists and has permission to operate.</div>
    <div style='margin-bottom:8px;'>Commond: <strong style='color:#ed980f'>chmod o=rwx -R %s</strong>.</div>
    </td></tr></table></body></html>
EOT;

==> ZenTaoPMS.15.7.1.zip: zentaopms/module/user/lang/de.php <==
<?php
/**
 * The user module English file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license     ZPL (http://zpl.pub/page/zplv12.html)
 * @author      Chunsheng Wang <chunsheng@cnezsoft.com>
 * @package     user
 * @version     $Id: en.php 5053 2013-07-06 08:17:37Z wyd621@gmail.com $
 * @link        http://www.zentao.net
 */
$lang->user->common           = 'Benutzer';
$lang->user->id               = 'ID';
$lang->user->inside           = 'Inside Members';
$lang->user->outside          = 'Outside Members';
$lang->user->company          = 'Unternehmen';
$lang->user->dept             = 'Abteilung';
$lang->user->account          = 'Konto';
$lang->user->password         = 'Passwort';
$lang->user->password2        = 'Passwort wiederholen';
$lang->user->role             = 'Rolle';
$lang->user->group            = 'Gruppe';
$lang->user->realname         = 'Name';
$lang->user->nickname         = 'Spitzname';
$lang->user->commiter         = 'SCM User';
$lang->user->birthyear        = 'Geburtsdatum';
$lang->user->gender           = 'Geschlecht';
$lang->user->email            = 'Email';
$lang->user->basicInfo        = 'Basis Info';
$lang->user->accountInfo      = 'Konto';
$lang->user->verify           = 'Bestätigen';
$lang->user->contactInfo      = 'Kontakt';
$lang->user->skype            = 'Skype';
$lang->user->qq               = 'QQ';
$lang->user->mobile           = 'Mobil';
$lang->user->phone            = 'Telefon';
$lang->user->weixin           = 'WeChat';
$lang->user->dingding         = 'DingDing';
$lang->user->slack            = 'Slack';
$lang->user->whatsapp         = 'WhatsApp';
$lang->user->address          = 'Adresse';
$lang->user->zipcode          = 'PLZ';
$lang->user->join             = 'Beigetreten am';
$lang->user->visits           = 'Besuche';
$lang->user->ip               = 'Letzte IP';
$lang->user->last             = 'Letztes Login';
$lang->user->ranzhi           = 'Zdoo Konto';
$lang->user->ditto            = 'Dito';
$lang->user->originalPassword = 'Altes Passwort';
$lang->user->newPassword      = 'New Password';
$lang->user->verifyPassword   = 'Ihr Login Passwort';
$lang->user->resetPassword    = 'Passwort vergessen?';
$lang->user->score            = 'Score';
$lang->user->name             = 'Name';
$lang->user->type             = 'User Type';
$lang->user->cropAvatar       = 'Crop Avatar';
$lang->user->cropAvatarTip    = 'Drag and drop the box to select the image clipping range.';
$lang->user->cropImageTip     = 'The image used is too small, the recommended image size is at least 48x48, the current image size is %s';

$lang->user->legendBasic        = 'Basic Information';
$lang->user->legendContribution = 'Contribution';

$lang->user->index         = "Home";
$lang->user->view          = "Übersicht";
$lang->user->create        = "Benutzer erstellen";
$lang->user->batchCreate   = "Mehrere erstellen";
$lang->user->edit          = "Bearbeiten";
$lang->user->batchEdit     = "Mehrere bearbeiten";
$lang->user->unlock        = "Entsperren";
$lang->user->delete        = "Löschen";
$lang->user->unbind        = "Zdoo verbindung aufheben";
$lang->user->login         = "Anmelden";
$lang->user->bind          = "Bind User";
$lang->user->oauthRegister = "Register a new account";
$lang->user->mobileLogin   = "Mobil";
$lang->user->editProfile   = "Bearbeiten";
$lang->user->deny          = "Zugriff verweigert.";
$lang->user->confirmDelete = "Möchten Sie diesen Benutzer löschen?";
$lang->user->confirmUnlock = "Möchten Sie diese Benutzer entsperren?";
$lang->user->confirmUnbind = "Möchten Sie dei Verknüpfung zu Zdoo aufheben?";
$lang->user->relogin       = "Erneut anmelden";
$lang->user->asGuest       = "Gast";
$lang->user->goback        = "Zurück";
$lang->user->deleted       = '(Gelöscht)';
$lang->user->search        = 'Suche';
$lang->user->else          = 'Else';

$lang->user->saveTemplate          = 'Save as Template';
$lang->user->setPublic             = 'Set as Public Template';
$lang->user->deleteTemplate        = 'Delete Template';
$lang->user->setTemplateTitle      = 'Please enter the title of template.';
$lang->user->applyTemplate         = 'Templates';
$lang->user->confirmDeleteTemplate = 'Do you want to delete this template?';
$lang->user->setPublicTemplate     = 'Set as Public Template';
$lang->user->tplContentNotEmpty    = 'Vorlageninhalt darf nicht leer sein!';

$lang->user->profile   = 'Profil';
$lang->user->project   = $lang->executionCommon;
$lang->user->execution = 'Execution';
$lang->user->task      = 'Aufgaben';
$lang->user->bug       = 'Bugs';
$lang->user->test      = 'Tests';
$lang->user->testTask  = 'Testaufgaben';
$lang->user->testCase  = 'Testfälle';
$lang->user->issue     = 'Issue';
$lang->user->risk      = 'Risk';
$lang->user->schedule  = 'Schedule';
$lang->user->todo      = 'Todos';
$lang->user->story     = 'Story';
$lang->user->dynamic   = 'Verlauf';

$lang->user->openedBy    = 'Geöffnet';
$lang->user->assignedTo  = 'Zugeordnet';
$lang->user->finishedBy  = 'Abgeschlossen';
$lang->user->resolvedBy  = 'Gelöst';
$lang->user->closedBy    = 'Geschlossen';
$lang->user->reviewedBy  = 'Überprüft';
$lang->user->canceledBy  = 'Abgebrochen';

$lang->user->testTask2Him = 'Build';
$lang->user->case2Him     = 'Fall zugeordnet';
$lang->user->caseByHim    = 'Fall geöffnet';

$lang->user->errorDeny    = "Sorry, your access to <b>%2\$s</b> of <b>%1\$s</b> is denied. Please contact your Admin to get privileges. Return to home page or login again.";
$lang->user->errorView    = "Sorry, your access view <b>%s</b> is denied. Please contact your Admin to get privileges. Return to home page or login again.";
$lang->user->loginFailed  = "Login fehlgeschlagen. Bitte prüfen Sie Ihren Benutzernamen und das Passwort.";
$lang->user->lockWarning  = "Sie haben %s Versuche.";
$lang->user->loginLocked  = "Bitte kontaktieren Sie den Administrator um Ihr Konto entsperren zu lassen oder versuchen Sie in %s Minuten noch ein mal.";
$lang->user->weakPassword = "Ihr Passwort entspricht nicht den Anforderungen.";
$lang->user->errorWeak    = "Passwords cannot use [%s] these commonly used weak passwords.";

$lang->user->roleList['']       = '';
$lang->user->roleList['dev']    = 'Developer';
$lang->user->roleList['qa']     = 'QS';
$lang->user->roleList['pm']     = 'Scrum Master';
$lang->user->roleList['po']     = 'Product Owner';
$lang->user->roleList['td']     = 'Technischer Manager';
$lang->user->roleList['pd']     = 'Produkt Manager';
$lang->user->roleList['qd']     = 'QS Manager';
$lang->user->roleList['top']    = 'Senior Manager';
$lang->user->roleList['others'] = 'Andere';

$lang->user->genderList['m'] = 'Männlich';
$lang->user->genderList['f'] = 'Weiblich';

$lang->user->thirdPerson['m'] = 'Him';
$lang->user->thirdPerson['f'] = 'Her';

$lang->user->typeList['inside']  = $lang->user->inside;
$lang->user->typeList['outside'] = $lang->user->outside;

$lang->user->passwordStrengthList[0] = "<span style='color:red'>Schwach</span>";
$lang->user->passwordStrengthList[1] = "<span style='color:#000'>Gut</span>";
$lang->user->passwordStrengthList[2] = "<span style='color:green'>Stark</span>";

$lang->user->statusList['active'] = 'Aktiviert';
$lang->user->statusList['delete'] = 'Gelöscht';

$lang->user->personalData['createdTodos']        = 'Todos Created';
$lang->user->personalData['createdRequirements'] = "Requirements Created";
$lang->user->personalData['createdStories']      = "Stories Created";
$lang->user->personalData['finishedTasks']       = 'Tasks Finished';
$lang->user->personalData['createdBugs']         = 'Bugs Created';
$lang->user->personalData['resolvedBugs']        = 'Bugs Resolved';
$lang->user->personalData['createdCases']        = 'Cases Created';
$lang->user->personalData['createdRisks']        = 'Risks Created';
$lang->user->personalData['resolvedRisks']       = 'Risks Resolved';
$lang->user->personalData['createdIssues']       = 'Issues Created';
$lang->user->personalData['resolvedIssues']      = 'Issues Resolved';
$lang->user->personalData['createdDocs']         = 'Docs Created';

$lang->user->keepLogin['on']      = 'Angemeldet bleiben';
$lang->user->loginWithDemoUser    = 'Login als Demo User:';

$lang->user->tpl = new stdclass();
$lang->user->tpl->type    = 'Typ';
$lang->user->tpl->title   = 'TPL Titel';
$lang->user->tpl->content = 'Inhalt';
$lang->user->tpl->public  = 'Öffentlich';

$lang->usertpl = new stdclass();
$lang->usertpl->title = 'Template Name';

$lang->user->placeholder = new stdclass();
$lang->user->placeholder->account   = 'Buchstaben, Understrich und Ziffern. Mindestens 3 Zeichen';
$lang->user->placeholder->password1 = 'Mindestens 6 Zeichen ';
$lang->user->placeholder->role      = "Rolle betrifft Inhalt und die Benutzerreihenfolge.";
$lang->user->placeholder->group     = "Die Gruppe bestimmt die Benutzerrechte.";
$lang->user->placeholder->commiter  = 'SVN/Git Konto';
$lang->user->placeholder->verify    = 'Bitte geben Sie Ihr Login Passwort ein.';

$lang->user->placeholder->passwordStrength[1] = 'Buchstaben und Ziffern. Mindestens 6 Zeichen';
$lang->user->placeholder->passwordStrength[2] = 'Buchstaben, Ziffern und Sonderzeichen. Mindestens 10 Zeichen';

$lang->user->error = new stdclass();
$lang->user->error->account        = "ID %s，Konto muss Buchstaben, Unterstriche oder Ziffern enthalten. Mindestens 3 Zeichen.";
$lang->user->error->accountDupl    = "ID %s，Konto wurde genutzt.";
$lang->user->error->realname       = "ID %s，muss der Realname sein";
$lang->user->error->password       = "ID %s，passwort muss mindestens 6 Zeichen lang sein.";
$lang->user->error->mail           = "ID %s，bitte geben Sie eine gültige Emailadresse an.";
$lang->user->error->reserved       = "ID %s，Konto ist reserviert.";
$lang->user->error->weakPassword   = "ID %s，the password strength is less than the system setting.";
$lang->user->error->dangerPassword = "ID %s，Passwords cannot be used with [%s] these commonly used if-passwords.";

$lang->user->error->verifyPassword   = "Verifikation fehlgeschlagen. Bitte geben Sie ihr Loginpasswort ein.";
$lang->user->error->originalPassword = "Altes Passwort ist falsch.";
$lang->user->error->noAccess         = "This user is not from your department. You have no access to this user information.";

$lang->user->contactFieldList['phone']    = $lang->user->phone;
$lang->user->contactFieldList['mobile']   = $lang->user->mobile;
$lang->user->contactFieldList['qq']       = $lang->user->qq;
$lang->user->contactFieldList['dingding'] = $lang->user->dingding;
$lang->user->contactFieldList['weixin']   = $lang->user->weixin;
$lang->user->contactFieldList['skype']    = $lang->user->skype;
$lang->user->contactFieldList['slack']    = $lang->user->slack;
$lang->user->contactFieldList['whatsapp'] = $lang->user->whatsapp;

$lang->user->executionTypeList['stage']  = 'Stage';
$lang->user->executionTypeList['sprint'] = $lang->iterationCommon;

$lang->user->contacts = new stdclass();
$lang->user->contacts->common   = 'Kontakt';
$lang->user->contacts->listName = 'Namensliste';
$lang->user->contacts->userList = 'Benutzerliste';

$lang->user->contacts->manage        = 'Verwalten';
$lang->user->contacts->contactsList  = 'Kontakte';
$lang->user->contacts->selectedUsers = 'Auswahl';
$lang->user->contacts->selectList    = 'Liste';
$lang->user->contacts->createList    = 'Erstelle Kontaktliste';
$lang->user->contacts->noListYet     = 'Es existiert keine Kontaktliste. Bitte erstellen Sie eine.';
$lang->user->contacts->confirmDelete = 'Möchten Sie diese Liste löschen?';
$lang->user->contacts->or            = ' oder ';

$lang->user->resetFail        = "Fehlgeschlagen. Bitte prüfen Sie das Konto";
$lang->user->resetSuccess     = "Zurückgesetzt! Bitte nutzen Sie Ihr neues Passwort, um sich anzumelden.";
$lang->user->noticeDelete     = 'Do you want to delete "%s" from ZenTao?';
$lang->user->noticeHasDeleted = "This user has been deleted. If you want to view it, please go to the Admin-System-Data-Recycle to restore it.";
$lang->user->noticeResetFile  = "<h5>Kontaktieren Sie den Administrator um Ihr Passwort zurückzusetzen.</h5>
    <h5>Wenn Sie der Administrator sind, meleden Sie sich auf dem Server an und erstellen Sie die Datei <span> '%s' </span>.</h5>
    <p>Hinweis:</p>
    <ol>
    <li>Die Datei muss leer sein.</li>
    <li>Wenn die Datei bereits existiert löschen Sie diese und erstellen Sie eine neue.</li>
    </ol>";
$lang->user->notice4Safe = "Warning: Weak password of one click package detected";
$lang->user->process4DIR = "It is detected that you may be using the one click installation package environment. Other sites in the environment are still using simple passwords. For security reasons, if you do not use other sites, please handle them in time. Delete or rename the %s directory. Visit: <a href='https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html' target='_blank'>https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html</a>";
$lang->user->process4DB  = "It is detected that you may be using the one click installation package environment. Other sites in the environment are still using simple passwords. For security reasons, if you do not use other sites, please handle them in time. Please login database and modify password field of zt_user table of %s database. Visit: <a href='https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html' target='_blank'>https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html</a>";
$lang->user->mkdirWin = <<<EOT
    <html><head><meta charset='utf-8'></head>
    <body><table align='center' style='width:700px; margin-top:100px; border:1px solid gray; font-size:14px;'><tr><td style='padding:8px'>
    <div style='margin-bottom:8px;'>不能创建临时目录，请确认目录<strong style='color:#ed980f'>%s</strong>是否存在并有操作权限。</div>
    <div>Can't create tmp directory, make sure the directory <strong style='color:#ed980f'>%s</strong> exists and has permission to operate.</div>
    </td></tr></table></body></html>
EOT;
$lang->user->mkdirLinux = <<<EOT
    <html><head><meta charset='utf-8'></head>
    <body><table align='center' style='width:700px; margin-top:100px; border:1px solid gray; font-size:14px;'><tr><td style='padding:8px'>
    <div style='margin-bottom:8px;'>不能创建临时目录，请确认目录<strong style='color:#ed980f'>%s</strong>是否存在并有操作权限。</div>
    <div style='margin-bottom:8px;'>命令为：<strong style='color:#ed980f'>chmod o=rwx -R %s</strong>。</div>
    <div>Can't create tmp directory, make sure the directory <strong style='color:#ed980f'>%s</strong> exists and has permission to operate.</div>
    <div style='margin-bottom:8px;'>Commond: <strong style='color:#ed980f'>chmod o=rwx -R %s</strong>.</div>
    </td></tr></table></body></html>
EOT;
